#ifndef NT2_INCLUDE_CONSTANTS_STIRLINGSPLITLIM_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_STIRLINGSPLITLIM_HPP_INCLUDED

#include <nt2/euler/include/constants/stirlingsplitlim.hpp>

#endif
